pub fn inter_processor_call(targets: &CpuSet, call_fn: fn()) -> PendingIpisExpand description
Executes a function on other processors.
The provided function call_fn will be executed on all target processors
specified by targets. It can also be executed on the current processor.
The function should be short and non-blocking, as it will be executed in
interrupt context with interrupts disabled.
The function call_fn will be executed asynchronously on the target
processors. However, if called on the current processor, it will be
synchronous.
The returned PendingIpis can be used to wait until all remote target
processors have handled IPIs for this call.
Panics
This function will panic if a hardware error occurs while sending an IPI to a remote processor.